/* 
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef __PXE_TYPES_H__
#define __PXE_TYPES_H__

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

#define IP_ADDR_LEN 4
#define MAC_ADDR_LEN 16

typedef union ip4_u {
    u_int32_t  num;
    u_int8_t   field[IP_ADDR_LEN];
} ip4_t;

typedef u_int8_t mac_addr_t[MAC_ADDR_LEN];
typedef u_int16_t udp_port_t;
typedef u_int16_t tftp_port_t;

/* This is returned by all the functions in the API in the 
 * AX register */
typedef enum pxenv_ret_code_e {
    PXENV_EXIT_SUCCESS,
    PXENV_EXIT_FAILURE
} pxenv_ret_code_t;

/* Real mode segment or protected mode selector. */
typedef u_int16_t segsel_t; 

/* Unsigned 16bit offset. */
typedef u_int16_t off16_t;
typedef u_int32_t addr32_t;
typedef u_int16_t pxenv_exit_t;
typedef u_int16_t pxenv_status_t;

typedef struct segoff16_s {
    off16_t offset;
    segsel_t segment;
} segoff16_t;

typedef struct segdesc_s {
    u_int16_t limit_low;
    u_int16_t base_low;
    u_int8_t base_mid;
    u_int8_t type;
    u_int8_t limit_high;
    u_int8_t base_high;
} segdesc_t;

typedef struct newsegdesc_s {
    u_int16_t seg_addr;
    u_int32_t phy_addr;
    u_int16_t seg_size;
} newsegdesc_t;

/* Loader & BUSD parameter structures.
 */
typedef struct bc_loader_s {
    pxenv_status_t status; 
    u_int16_t  _ax_;   
    u_int16_t  _bx_;   
    u_int16_t  _dx_;   
    u_int16_t  _di_;   
    u_int16_t  _es_;   
    u_int16_t  undi_romid_off; 
    u_int16_t  undi_romid_seg; 
} bc_loader_t;

typedef struct undi_loader_s {
    pxenv_status_t status; 
    u_int16_t  _ax_;   
    u_int16_t  _bx_;   
    u_int16_t  _dx_;   
    u_int16_t  _di_;   
    u_int16_t  _es_;   
    u_int16_t  undi_ds;        
    u_int16_t  undi_cs;        
    segoff16_t pxeptr;
    segoff16_t pxenvptr;
} undi_loader_t;

typedef struct busd_enable_s {
    pxenv_status_t status; 
    u_int16_t  _ax_;   
    u_int16_t  _bx_;   
    u_int16_t  _dx_;   
    u_int16_t  _di_;   
    u_int16_t  _es_;   
    u_int16_t  undi_romid_off; 
    u_int16_t  undi_romid_seg; 
} busd_enable_t;

typedef struct busd_disable_s {
    pxenv_status_t status; 
    u_int16_t  _ax_;   
    u_int16_t  _bx_;   
    u_int16_t  _dx_;   
    u_int16_t  _di_;   
    u_int16_t  _es_;   
    u_int16_t  undi_romid_off; 
    u_int16_t  undi_romid_seg; 
} busd_disable_t;

#endif /* __PXE_TYPES_H__ */

