/* 
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

/* Define the PXE types */
#include "pxe_types.h"

/* Define the tracing macros */
#include "trace.h"

/* Define the UDP data structures */
#include "pxe_udp.h"

/* pxenv_udp_open() - open the UDP connection. There can only be
 *      one open UDP connection at a time.
 *
 * parameters:
 *     none
 *
 * returns:
 *     udpwrite.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 *     udpopen.src_ip - the IP number of this node.
 */
pxenv_ret_code_t
pxenv_udp_open (pxenv_udp_open_t updopen)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_udp_close() - close the currently open UDP connection.
 *
 * parameters:
 *     none
 * returns:
 *     udpwrite.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_udp_close (pxenv_udp_close_t udpclose)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_udp_read() - read one packet using an already opened UDP
 *      connection.
 *
 * parameters:
 *     udpread.dest_ip - if non-zero, filter all incoming
 *                packets and receive the ones for this IP address. If
 *                UDP_READ_ANY_IP (zero), then read any packet.
 *     udpread.d_port - if non-zero, filter all incoming packets
 *               and receive the ones for this UDP port. If
 *               UDP_READ_ANY_PORT (zero), then read any packet.
 *     udpread.buffer_size - size of the receive buffer.
 *     udpread.buffer - the segment the buffer is in.
 *
 * returns:
 *     udpwrite.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 *     udpread.src_ip - The IP number of the sending node.
 *     udpread.dest_ip - If this parameter was UDP_READ_ANY_IP
 *                      (zero), then return the destination IP number.
 *     udpread.s_port - The UDP port number of the sending node. 
 *     udpread.d_port - If this parameter was zero, then
 *                        return the  destination UDP port.
 *     udpread.buffer_size - Number of bytes written into
 *                        the receive buffer.
 */
pxenv_ret_code_t
pxenv_udp_read (pxenv_udp_read_t udpread)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_udp_write() - writes one packet to the requested UDP port
 *      using an already opened UDP connection.
 *
 * parameters:
 *     udpwrite.dest_ip - the IP number of the destination.
 *     udpwrite.gw_ip - the ip number of the gateway.
 *     udpwrite.src_port - the UDP port of the sender,
 *                         defaults to 2069 if this flag is zero.
 *     udpwrite.dest_port - the UDP port of the destination.
 *     udpwrite.buffer_size - size of the transmit buffer.
 *     udpwrite.buffer - the buffer address in offset:segment format.
 *
 * returns:
 *     udpwrite.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_udp_write (pxenv_udp_write_t udpwrite)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}



